aboutsummaryrefslogtreecommitdiff
path: root/conn/conn.go
diff options
context:
space:
mode:
Diffstat (limited to 'conn/conn.go')
-rw-r--r--conn/conn.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/conn/conn.go b/conn/conn.go
index 16311e4..6e04386 100644
--- a/conn/conn.go
+++ b/conn/conn.go
@@ -50,11 +50,11 @@ func CreateBind(port uint16) (b Bind, actualPort uint16, err error) {
return createBind(port)
}
// BindToInterface is implemented by Bind objects that support being
// tied to a single network interface.
-type BindToInterface interface {
- BindToInterface4(interfaceIndex uint32, blackhole bool) error
- BindToInterface6(interfaceIndex uint32, blackhole bool) error
+type BindSocketToInterface interface {
+ BindSocketToInterface4(interfaceIndex uint32, blackhole bool) error
+ BindSocketToInterface6(interfaceIndex uint32, blackhole bool) error
}
// An Endpoint maintains the source/destination caching for a peer.
@@ -50,11 +50,11 @@ func CreateBind(port uint16) (b Bind, actualPort uint16, err error) {
return createBind(port)
}
-// BindToInterface is implemented by Bind objects that support being
+// BindSocketToInterface is implemented by Bind objects that support being
// tied to a single network interface.